@@ -17,7 +17,7 @@ Simply run this script in a directory containing a buildout.cfg.
 The script accepts buildout command-line options, so you can
 use the -c option to specify an alternate configuration file.
 
-$Id: bootstrap.py 70971 2008-09-01 12:02:12Z gawel $
+$Id: bootstrap.py 85008 2009-04-24 12:06:54Z tarek $
 """
 import glob
 import os
@@ -50,7 +50,7 @@ def _import(egg_name):
             folder_name = os.path.split(path_)[-1]
             target = os.path.join(eggs_folder, folder_name)
             if target.lower() == path_.lower():
-                return 
+                return
             if os.path.exists(target):
                 shutil.rmtree(target)
             shutil.copytree(path_, target)
@@ -87,12 +87,6 @@ def link_egg(working_set, egg_name, required=True):
             working_set.require(egg_name)
             _import(egg_name)
 
-    #sys.path.insert(0, egg_location)
-    #working_set.add_entry(egg_name)
-    #working_set.require(egg_name)
-    
-    #return egg_location 
-
 #
 # setuptool install
 #
@@ -117,7 +111,7 @@ else:
         ez = {}
         exec urllib2.urlopen(EZ_SETUP).read() in ez
         ez['use_setuptools'](to_dir=eggs_folder, download_delay=0)
-        
+
 ws = pkg_resources.working_set
 link_egg(ws, 'zc.buildout')
 
