@@ -23,6 +23,7 @@ import md5
 import re
 import sys
 import shutil
+import distutils
 from glob import glob
 from fnmatch import fnmatch
 from tempfile import mkdtemp
@@ -379,6 +380,16 @@ def _make_python(location='.'):
                         os.chmod(join(dirname, wanted), 755)
                     except OSError:
                         pass # win32 error, or rights error
+
+                # Make sure to also copy distutils.cfg, if existing
+                # This allows mingw32 to work inside the virtualenv too
+                distutils_path = distutils.__path__[0]
+                distutils_cfg = os.path.join(distutils_path, 'distutils.cfg')
+                if os.path.exists(distutils_cfg):
+                    distutils_dir = os.path.join(home_dir, 'lib', 'distutils')
+                    dest = os.path.join(distutils_dir, 'distutils.cfg')
+                    shutil.copyfile(distutils_cfg, dest)
+
             main()
             #XXX: this is a hack: the after_install is never called in
             # the main(). This should be fixed otherway
